From 4d0fc1d54b465d4a40b3cf89908438533680e7f3 Mon Sep 17 00:00:00 2001
From: Tom Lane <tgl@sss.pgh.pa.us>
Date: Wed, 16 Sep 2015 12:08:57 -0400
Subject: [PATCH] Don't use "#" as an abbreviation for "number" in PL/Tcl error
 messages.

Also, rewrite one error message to make it follow our message style
guidelines better.

Euler Taveira and Tom Lane
---
 src/pl/tcl/pltcl.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/pl/tcl/pltcl.c b/src/pl/tcl/pltcl.c
index edfda5915b2..dce5d04adf8 100644
--- a/src/pl/tcl/pltcl.c
+++ b/src/pl/tcl/pltcl.c
@@ -1055,7 +1055,7 @@ pltcl_trigger_handler(PG_FUNCTION_ARGS, bool pltrusted)
 		if (ret_numvals % 2 != 0)
 			ereport(ERROR,
 					(errcode(ERRCODE_E_R_I_E_TRIGGER_PROTOCOL_VIOLATED),
-					 errmsg("invalid return list from trigger - must have even # of elements")));
+					 errmsg("trigger's return list must have even number of elements")));
 
 		modattrs = (int *) palloc(tupdesc->natts * sizeof(int));
 		modvalues = (Datum *) palloc(tupdesc->natts * sizeof(Datum));
@@ -2345,7 +2345,7 @@ pltcl_SPI_execute_plan(ClientData cdata, Tcl_Interp *interp,
 		if (strlen(nulls) != qdesc->nargs)
 		{
 			Tcl_SetResult(interp,
-					   "length of nulls string doesn't match # of arguments",
+				  "length of nulls string doesn't match number of arguments",
 						  TCL_STATIC);
 			return TCL_ERROR;
 		}
@@ -2370,12 +2370,12 @@ pltcl_SPI_execute_plan(ClientData cdata, Tcl_Interp *interp,
 			return TCL_ERROR;
 
 		/************************************************************
 		 * Check that the # of arguments matches
 		 ************************************************************/
 		if (callnargs != qdesc->nargs)
 		{
 			Tcl_SetResult(interp,
-			   "argument list length doesn't match # of arguments for query",
+						  "argument list length doesn't match number of arguments for query",
 						  TCL_STATIC);
 			ckfree((char *) callargs);
 			return TCL_ERROR;
@@ -2370,12 +2370,12 @@ pltcl_SPI_execute_plan(ClientData cdata, Tcl_Interp *interp,
 
 		/************************************************************
-		 * Check that the # of arguments matches
+		 * Check that the number of arguments matches
 		 ************************************************************/
 		if (callnargs != qdesc->nargs)
-- 
GitLab